Exception: RubyLLM::Modes::ContractError

Inherits:
Error
  • Object
show all
Defined in:
lib/ruby_llm/modes/errors.rb

Overview

A classifier returned something outside the classifier contract: not a Decision, a mode_name or reason that is not a String, a confidence that is NaN or outside 0..1, probabilities that are not a Hash of numbers, or a chat response that is not a JSON object.